window.Gleam.initSearch([{"doc":"ansel","title":"ansel","content":"# Ansel\n\nA simple and fast vips image processing library for Gleam!\n\n[![Package Version](https://img.shields.io/hexpm/v/ansel)](https://hex.pm/packages/ansel)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/ansel/)\n\nThis library uses the [snag package](https://hexdocs.pm/snag/index.html) for error handling because vix errors are plentiful, come back as strings, and have not been enumerated. Install it as well to work with the error messages.\n\nThe great vips library is used as the image processing backend, via the fantastic Elixir Vix package. Elixir must be installed to compile this package. The pre-compiled vips binary that comes with Vix supports the most common image formats, but a custom built vips binary can be provided to support even more. See more details about this below.\n\n```sh\ngleam add ansel\n```\n\n## Resizing Images\n\n```gleam\nimport ansel/image\nimport ansel/color\nimport gleam/result\nimport snag\n\npub fn main() {\n  let assert Ok(img) = image.read(&quot;input.jpeg&quot;)\n\n  image.round(img, by: 20.0)\n  |&gt; result.try(image.border(_, with: color.GleamLucy, thickness: 6))\n  |&gt; result.try(image.scale_width(_, to: 600))\n  |&gt; result.try(\n    image.write(_, &quot;output&quot;, image.JPEG(quality: 60, keep_metadata: False)),\n  )\n  |&gt; snag.context(&quot;Failed processing input.jpeg&quot;)\n}\n// -&gt; output.jpeg written to disk as a smaller and rounded bordered version of\n//    the original image\n```\n\n## Extracting From and Layering Images\n\n```gleam\nimport ansel/image\nimport ansel/bounding_box\nimport gleam/result\n\npub fn main() {\n  use img1 &lt;- result.try(image.read(&quot;input1.heic&quot;))\n  use img2 &lt;- result.try(image.read(&quot;input2.png&quot;))\n\n  use bounds &lt;- result.try(bounding_box.ltwh(800, 800, 500, 500))\n\n  use extract &lt;- result.try(image.extract_area(img1, at: bounds))\n\n  use composite &lt;- result.try(\n    image.composite_over(img2, with: extract, at_left: 400, at_top: 300),\n  )\n\n  image.write(composite, &quot;output&quot;, image.PNG)\n}\n// -&gt; output.png written to disk with a 500x500 pixel area from input1 layered\n//    on top of input2 starting at the coordinate 400, 300\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/ansel&gt;.\n\n## Additional Image Format Support\n\nVix comes with a pre-compiled vips binary, but a custom built vips binary can be provided on the host system to use with this package as well by setting the host system environment variable `VIX_COMPILATION_MODE` to `PLATFORM_PROVIDED_LIBVIPS` before compiling. Vips can be configured to work with many different image formats, but they are dependent on the libraries you build it with. For this reason, you may want to install your own image encoders and decoders to support the formats you need, then bring your own vips binary to use with this package. More information can be found in the [vips documentation](https://github.com/libvips/libvips?tab=readme-ov-file#optional-dependencies).\n\neg. on Linux, to bring your own heif encoders / decoders:\n\n```\nsudo apt install libvips-tools\nsudo apt install libvips-dev\nsudo apt install libheif\nexport VIX_COMPILATION_MODE=PLATFORM_PROVIDED_LIBVIPS\ngleam clean\ngleam run\n```\n\n## Development\n\n```sh\ngleam test  # Run the tests\n```\n","url":"index.html"},{"doc":"ansel","title":"Image","content":"pub type Image\n A reference to a vips image instance. It is the basis for all image \n operations.\n\nSynonyms:\nansel.Image\nansel Image","url":"ansel.html#Image"},{"doc":"ansel","title":"ansel","content":" This module provides the image type for the other modules in this package.","url":"ansel.html"},{"doc":"ansel/bounding_box","title":"BoundingBox","content":"pub opaque type BoundingBox\n A representation of a rectangular area in any given image.\n\nSynonyms:\nansel/bounding_box.BoundingBox\nansel/bounding_box BoundingBox","url":"ansel/bounding_box.html#BoundingBox"},{"doc":"ansel/bounding_box","title":"cut","content":"pub fn cut(\n  out_of to_cut: BoundingBox,\n  with cutter: BoundingBox,\n) -&gt; List(BoundingBox)\n Cuts a bounding box out of another bounding box, returning a list of \n bounding boxes that represent the area of the original that was not cut out.\nSynonyms:\nansel/bounding_box.cut\nansel/bounding_box cut","url":"ansel/bounding_box.html#cut"},{"doc":"ansel/bounding_box","title":"expand","content":"pub fn expand(\n  bounding_box: BoundingBox,\n  by amount: Int,\n) -&gt; BoundingBox\n Expands a bounding box by the given amount in all dimensions. If the amount \n is negative, the bounding box will not be modified.\nSynonyms:\nansel/bounding_box.expand\nansel/bounding_box expand","url":"ansel/bounding_box.html#expand"},{"doc":"ansel/bounding_box","title":"fit","content":"pub fn fit(\n  box: BoundingBox,\n  into reference: BoundingBox,\n) -&gt; Option(BoundingBox)\n Fits a bounding box into another bounding box, dropping any pixels outside \n the dimensions of the reference bounding box.\nSynonyms:\nansel/bounding_box.fit\nansel/bounding_box fit","url":"ansel/bounding_box.html#fit"},{"doc":"ansel/bounding_box","title":"intersection","content":"pub fn intersection(\n  of box1: BoundingBox,\n  with box2: BoundingBox,\n) -&gt; Option(BoundingBox)\n Returns the intersection of two bounding boxes. If they do not intersect,\n `None` will be returned.\nSynonyms:\nansel/bounding_box.intersection\nansel/bounding_box intersection","url":"ansel/bounding_box.html#intersection"},{"doc":"ansel/bounding_box","title":"ltrb","content":"pub fn ltrb(\n  left left: Int,\n  top top: Int,\n  right right: Int,\n  bottom bottom: Int,\n) -&gt; Result(BoundingBox, Snag)\n Creates a new bounding box from the given values in the (Left, Top), (Right, \n Bottom) rectangular coordinate format.\nSynonyms:\nansel/bounding_box.ltrb\nansel/bounding_box ltrb","url":"ansel/bounding_box.html#ltrb"},{"doc":"ansel/bounding_box","title":"ltwh","content":"pub fn ltwh(\n  left left: Int,\n  top top: Int,\n  width width: Int,\n  height height: Int,\n) -&gt; Result(BoundingBox, Snag)\n Creates a new bounding box from the given values in the (Left, Top), (Width, \n Height) rectangular coordinate format.\nSynonyms:\nansel/bounding_box.ltwh\nansel/bounding_box ltwh","url":"ansel/bounding_box.html#ltwh"},{"doc":"ansel/bounding_box","title":"make_relative","content":"pub fn make_relative(\n  box: BoundingBox,\n  to reference: BoundingBox,\n) -&gt; Option(BoundingBox)\n Makes a bounding box relative to and fit inside another bounding box. \n Assuming both bounding boxes are on the same image, they are both relative\n to 0,0 on that image. This adjusts the first bounding box so that the \n original coordinates are relative to the top left corner of the second \n bounding box instead, and then fits the adjusted bounding box into the \n reference bounding box.\n \n This is useful when you have two bounding boxes on an image, where one\n represents an extracted area of the original image and you want to do\n an operation on that extracted area with the second bounding box, but the \n second bounding box was calculated with the coordinates of the original \n image.\n \n ## Example\n \n let assert Ok(box) = bounding_box.ltwh(left: 2, top: 2, width: 4, height: 4) \n let assert Ok(ref) = bounding_box.ltwh(left: 4, top: 4, width: 6, height: 6) \n bounding_box.make_relative(box, to: ref)\n // -&gt; Some(bounding_box.ltwh(left: 0, top: 0, width: 2, height: 2))\n \nSynonyms:\nansel/bounding_box.make_relative\nansel/bounding_box make_relative","url":"ansel/bounding_box.html#make_relative"},{"doc":"ansel/bounding_box","title":"scale","content":"pub fn scale(\n  bounding_box: BoundingBox,\n  by scale: Float,\n) -&gt; BoundingBox\n Resizes a bounding box by the given scale.\nSynonyms:\nansel/bounding_box.scale\nansel/bounding_box scale","url":"ansel/bounding_box.html#scale"},{"doc":"ansel/bounding_box","title":"shrink","content":"pub fn shrink(\n  bounding_box: BoundingBox,\n  by amount: Int,\n) -&gt; Result(BoundingBox, Nil)\n Shrinks a bounding box by the given amount in all dimensions. If the amount \n is negative, the bounding box will not be modified. If the amount to shrink \n is greater than the size of the bounding box, an error will be returned.\nSynonyms:\nansel/bounding_box.shrink\nansel/bounding_box shrink","url":"ansel/bounding_box.html#shrink"},{"doc":"ansel/bounding_box","title":"to_ltrb_tuple","content":"pub fn to_ltrb_tuple(\n  bounding_box: BoundingBox,\n) -&gt; #(Int, Int, Int, Int)\n Converts a bounding box to a tuple with the coordinate values left, top, \n right, bottom. Useful for working with with custom bounding box operations.\n \n ## Example\n \n let assert Ok(box) = bounding_box.x1y1x2y2(x1: 2, y1: 2, x2: 6, y2: 6) \n bounding_box.to_ltrb_tuple(box)\n // -&gt; #(2, 2, 6, 6)\n \nSynonyms:\nansel/bounding_box.to_ltrb_tuple\nansel/bounding_box to_ltrb_tuple","url":"ansel/bounding_box.html#to_ltrb_tuple"},{"doc":"ansel/bounding_box","title":"to_ltwh_tuple","content":"pub fn to_ltwh_tuple(\n  bounding_box: BoundingBox,\n) -&gt; #(Int, Int, Int, Int)\n Converts a bounding box to a tuple with the coordinate values left, top, \n width, height. Useful for working with with custom bounding box operations\n and getting the width and height of a bounding box.\n \n ## Example\n \n let assert Ok(box) = bounding_box.x1y1x2y2(x1: 2, y1: 2, x2: 6, y2: 6) \n bounding_box.to_ltwh_tuple(box)\n // -&gt; #(2, 2, 4, 4)\n \n \n \n let assert Ok(box) = bounding_box.x1y1x2y2(x1: 4, y1: 4, x2: 10, y2: 10) \n let #(_, _, width, height) = bounding_box.to_ltwh_tuple(box)\n // -&gt; 6, 6\n \nSynonyms:\nansel/bounding_box.to_ltwh_tuple\nansel/bounding_box to_ltwh_tuple","url":"ansel/bounding_box.html#to_ltwh_tuple"},{"doc":"ansel/bounding_box","title":"to_x1y1x2y2_tuple","content":"pub fn to_x1y1x2y2_tuple(\n  bounding_box: BoundingBox,\n) -&gt; #(Int, Int, Int, Int)\n Converts a bounding box to a tuple with the coordinate values x1, y1, x2, \n y2. Useful for working with with custom bounding box operations.\n \n ## Example\n \n let assert Ok(box) = bounding_box.ltwh(2, 2, 4, 4) \n bounding_box.to_x1y1x2y2_tuple(box)\n // -&gt; #(2, 2, 6, 6)\n \nSynonyms:\nansel/bounding_box.to_x1y1x2y2_tuple\nansel/bounding_box to_x1y1x2y2_tuple","url":"ansel/bounding_box.html#to_x1y1x2y2_tuple"},{"doc":"ansel/bounding_box","title":"x1y1x2y2","content":"pub fn x1y1x2y2(\n  x1 x1: Int,\n  y1 y1: Int,\n  x2 x2: Int,\n  y2 y2: Int,\n) -&gt; Result(BoundingBox, Snag)\n Creates a new bounding box from the given values in the (x1, y1), (x2, y2) \n rectangular coordinate format.\nSynonyms:\nansel/bounding_box.x1y1x2y2\nansel/bounding_box x1y1x2y2","url":"ansel/bounding_box.html#x1y1x2y2"},{"doc":"ansel/bounding_box","title":"ansel/bounding_box","content":" A module for working with bounding boxes in Ansel. Bounding boxes are a \n common way to represent rectangular areas in images, and can be used to \n crop images, fill in images, and highlight areas of images.\n \n ```gleam\n let assert Ok(box) = bounding_box.x1y1x2y2(2, 2, 4, 4)\n \n bounding_box.expand(box, by: 2)\n |&gt; image.extract_area(image, at: _)\n ```","url":"ansel/bounding_box.html"},{"doc":"ansel/color","title":"Color","content":"pub type Color {\n  RGBA(r: Int, g: Int, b: Int, a: Int)\n  RGB(r: Int, g: Int, b: Int)\n  GleamLucy\n  GleamNavy\n  Maroon\n  DarkRed\n  Brown\n  Firebrick\n  Crimson\n  Red\n  Tomato\n  Coral\n  IndianRed\n  LightCoral\n  DarkSalmon\n  Salmon\n  LightSalmon\n  OrangeRed\n  DarkOrange\n  Orange\n  Gold\n  DarkGoldenRod\n  GoldenRod\n  PaleGoldenRod\n  DarkKhaki\n  Khaki\n  Olive\n  Yellow\n  YellowGreen\n  DarkOliveGreen\n  OliveDrab\n  LawnGreen\n  Chartreuse\n  GreenYellow\n  DarkGreen\n  Green\n  ForestGreen\n  Lime\n  LimeGreen\n  LightGreen\n  PaleGreen\n  DarkSeaGreen\n  MediumSpringGreen\n  SpringGreen\n  SeaGreen\n  MediumAquaMarine\n  MediumSeaGreen\n  LightSeaGreen\n  DarkSlateGray\n  Teal\n  DarkCyan\n  Aqua\n  Cyan\n  LightCyan\n  DarkTurquoise\n  Turquoise\n  MediumTurquoise\n  PaleTurquoise\n  AquaMarine\n  PowderBlue\n  CadetBlue\n  SteelBlue\n  CornFlowerBlue\n  DeepSkyBlue\n  DodgerBlue\n  LightBlue\n  SkyBlue\n  LightSkyBlue\n  MidnightBlue\n  Navy\n  DarkBlue\n  MediumBlue\n  Blue\n  RoyalBlue\n  BlueViolet\n  Indigo\n  DarkSlateBlue\n  SlateBlue\n  MediumSlateBlue\n  MediumPurple\n  DarkMagenta\n  DarkViolet\n  DarkOrchid\n  MediumOrchid\n  Purple\n  Thistle\n  Plum\n  Violet\n  Magenta\n  Fuchsia\n  Orchid\n  MediumVioletRed\n  PaleVioletRed\n  DeepPink\n  HotPink\n  LightPink\n  Pink\n  AntiqueWhite\n  Beige\n  Bisque\n  BlanchedAlmond\n  Wheat\n  CornSilk\n  LemonChiffon\n  LightGoldenRodYellow\n  LightYellow\n  SaddleBrown\n  Sienna\n  Chocolate\n  Peru\n  SandyBrown\n  BurlyWood\n  Tan\n  RosyBrown\n  Moccasin\n  NavajoWhite\n  PeachPuff\n  MistyRose\n  LavenderBlush\n  Linen\n  OldLace\n  PapayaWhip\n  SeaShell\n  MintCream\n  SlateGray\n  LightSlateGray\n  LightSteelBlue\n  Lavender\n  FloralWhite\n  AliceBlue\n  GhostWhite\n  Honeydew\n  Ivory\n  Azure\n  Snow\n  Black\n  DimGray\n  DimGrey\n  Gray\n  Grey\n  DarkGray\n  DarkGrey\n  Silver\n  LightGray\n  LightGrey\n  Gainsboro\n  WhiteSmoke\n  White\n}\n Colors supported by Ansel operations. The RGB and RGBA constructors can be\n used to create custom colors. Of course, the GleamLucy and GleamNavy colors\n are included ;)\nRGBA(r: Int, g: Int, b: Int, a: Int)\n\n\nRGB(r: Int, g: Int, b: Int)\n\n\nGleamLucy\n\n\nGleamNavy\n\n\nMaroon\n\n\nDarkRed\n\n\nBrown\n\n\nFirebrick\n\n\nCrimson\n\n\nRed\n\n\nTomato\n\n\nCoral\n\n\nIndianRed\n\n\nLightCoral\n\n\nDarkSalmon\n\n\nSalmon\n\n\nLightSalmon\n\n\nOrangeRed\n\n\nDarkOrange\n\n\nOrange\n\n\nGold\n\n\nDarkGoldenRod\n\n\nGoldenRod\n\n\nPaleGoldenRod\n\n\nDarkKhaki\n\n\nKhaki\n\n\nOlive\n\n\nYellow\n\n\nYellowGreen\n\n\nDarkOliveGreen\n\n\nOliveDrab\n\n\nLawnGreen\n\n\nChartreuse\n\n\nGreenYellow\n\n\nDarkGreen\n\n\nGreen\n\n\nForestGreen\n\n\nLime\n\n\nLimeGreen\n\n\nLightGreen\n\n\nPaleGreen\n\n\nDarkSeaGreen\n\n\nMediumSpringGreen\n\n\nSpringGreen\n\n\nSeaGreen\n\n\nMediumAquaMarine\n\n\nMediumSeaGreen\n\n\nLightSeaGreen\n\n\nDarkSlateGray\n\n\nTeal\n\n\nDarkCyan\n\n\nAqua\n\n\nCyan\n\n\nLightCyan\n\n\nDarkTurquoise\n\n\nTurquoise\n\n\nMediumTurquoise\n\n\nPaleTurquoise\n\n\nAquaMarine\n\n\nPowderBlue\n\n\nCadetBlue\n\n\nSteelBlue\n\n\nCornFlowerBlue\n\n\nDeepSkyBlue\n\n\nDodgerBlue\n\n\nLightBlue\n\n\nSkyBlue\n\n\nLightSkyBlue\n\n\nMidnightBlue\n\n\nNavy\n\n\nDarkBlue\n\n\nMediumBlue\n\n\nBlue\n\n\nRoyalBlue\n\n\nBlueViolet\n\n\nIndigo\n\n\nDarkSlateBlue\n\n\nSlateBlue\n\n\nMediumSlateBlue\n\n\nMediumPurple\n\n\nDarkMagenta\n\n\nDarkViolet\n\n\nDarkOrchid\n\n\nMediumOrchid\n\n\nPurple\n\n\nThistle\n\n\nPlum\n\n\nViolet\n\n\nMagenta\n\n\nFuchsia\n\n\nOrchid\n\n\nMediumVioletRed\n\n\nPaleVioletRed\n\n\nDeepPink\n\n\nHotPink\n\n\nLightPink\n\n\nPink\n\n\nAntiqueWhite\n\n\nBeige\n\n\nBisque\n\n\nBlanchedAlmond\n\n\nWheat\n\n\nCornSilk\n\n\nLemonChiffon\n\n\nLightGoldenRodYellow\n\n\nLightYellow\n\n\nSaddleBrown\n\n\nSienna\n\n\nChocolate\n\n\nPeru\n\n\nSandyBrown\n\n\nBurlyWood\n\n\nTan\n\n\nRosyBrown\n\n\nMoccasin\n\n\nNavajoWhite\n\n\nPeachPuff\n\n\nMistyRose\n\n\nLavenderBlush\n\n\nLinen\n\n\nOldLace\n\n\nPapayaWhip\n\n\nSeaShell\n\n\nMintCream\n\n\nSlateGray\n\n\nLightSlateGray\n\n\nLightSteelBlue\n\n\nLavender\n\n\nFloralWhite\n\n\nAliceBlue\n\n\nGhostWhite\n\n\nHoneydew\n\n\nIvory\n\n\nAzure\n\n\nSnow\n\n\nBlack\n\n\nDimGray\n\n\nDimGrey\n\n\nGray\n\n\nGrey\n\n\nDarkGray\n\n\nDarkGrey\n\n\nSilver\n\n\nLightGray\n\n\nLightGrey\n\n\nGainsboro\n\n\nWhiteSmoke\n\n\nWhite\n\n\nSynonyms:\nansel/color.Color\nansel/color Color","url":"ansel/color.html#Color"},{"doc":"ansel/color","title":"add_alpha_band","content":"pub fn add_alpha_band(to color: Color, of alpha: Int) -&gt; Color\n Adds an alpha band of the given value to a color, possibly making it\n partially transparent.\n \n ## Example\n \n color.add_alpha_band(color.GleamLucy, of: 128)\n |&gt; color.to_rgba_tuple\n // -&gt; #(255, 175, 243, 128)\n \nSynonyms:\nansel/color.add_alpha_band\nansel/color add_alpha_band","url":"ansel/color.html#add_alpha_band"},{"doc":"ansel/color","title":"to_bands","content":"pub fn to_bands(color: Color) -&gt; List(Int)\n Returns a color as a list of integer rbg or rbga bands\n \n ## Example\n \n color.to_bands(color.GleamLucy)\n // -&gt; [255, 175, 243]\n \nSynonyms:\nansel/color.to_bands\nansel/color to_bands","url":"ansel/color.html#to_bands"},{"doc":"ansel/color","title":"to_rgb_tuple","content":"pub fn to_rgb_tuple(color: Color) -&gt; #(Int, Int, Int)\n Returns a color as a tuple of integer rgb bands\n \n ## Example\n \n color.to_rgb_tuple(color.GleamLucy)\n // -&gt; #(255, 175, 243)\n \nSynonyms:\nansel/color.to_rgb_tuple\nansel/color to_rgb_tuple","url":"ansel/color.html#to_rgb_tuple"},{"doc":"ansel/color","title":"to_rgba_tuple","content":"pub fn to_rgba_tuple(color: Color) -&gt; #(Int, Int, Int, Int)\n Returns a color as a tuple of integer rgba bands\n \n ## Example\n \n color.to_rgba_tuple(color.GleamLucy)\n // -&gt; #(255, 175, 243, 255)\n \nSynonyms:\nansel/color.to_rgba_tuple\nansel/color to_rgba_tuple","url":"ansel/color.html#to_rgba_tuple"},{"doc":"ansel/color","title":"ansel/color","content":" Predefined colors and color functions to be used with Ansel image \n operations.","url":"ansel/color.html"},{"doc":"ansel/image","title":"ImageFormat","content":"pub type ImageFormat {\n  JPEG(quality: Int, keep_metadata: Bool)\n  JPEG2000(quality: Int, keep_metadata: Bool)\n  JPEGXL(quality: Int, keep_metadata: Bool)\n  PNG\n  WebP(quality: Int, keep_metadata: Bool)\n  AVIF(quality: Int, keep_metadata: Bool)\n  TIFF(quality: Int, keep_metadata: Bool)\n  HEIC(quality: Int, keep_metadata: Bool)\n  FITS\n  Matlab\n  PDF\n  SVG\n  HDR\n  PPM\n  CSV\n  GIF\n  Analyze\n  NIfTI\n  DeepZoom\n  Custom(format: String)\n}\n Image formats supported by vips. All may not be supported by the default\n vips binary included with this package, you may need to provide your\n own vips binary on the host system to. See the package readme for details.\n \n The `Custom` constructor allows for advanced vips save options to be \n used, like `ansel.Custom(&quot;.png[compression=90,squash=true]&quot;), refer to the \n [Vix package documentation](https://hexdocs.pm/vix/Vix.Vips.Image.html#write_to_file/2) \n for details.\nJPEG(quality: Int, keep_metadata: Bool)\n\n\nJPEG2000(quality: Int, keep_metadata: Bool)\n\n\nJPEGXL(quality: Int, keep_metadata: Bool)\n\n\nPNG\n\n\nWebP(quality: Int, keep_metadata: Bool)\n\n\nAVIF(quality: Int, keep_metadata: Bool)\n\n\nTIFF(quality: Int, keep_metadata: Bool)\n\n\nHEIC(quality: Int, keep_metadata: Bool)\n\n\nFITS\n\n\nMatlab\n\n\nPDF\n\n\nSVG\n\n\nHDR\n\n\nPPM\n\n\nCSV\n\n\nGIF\n\n\nAnalyze\n\n\nNIfTI\n\n\nDeepZoom\n\n\nCustom(format: String)\n\n\nSynonyms:\nansel/image.ImageFormat\nansel/image ImageFormat","url":"ansel/image.html#ImageFormat"},{"doc":"ansel/image","title":"blur","content":"pub fn blur(\n  image image: Image,\n  with sigma: Float,\n) -&gt; Result(Image, Snag)\n Applies a gaussian blur with the given sigma value to an image.\nSynonyms:\nansel/image.blur\nansel/image blur","url":"ansel/image.html#blur"},{"doc":"ansel/image","title":"border","content":"pub fn border(\n  around image: Image,\n  with color: Color,\n  thickness thickness: Int,\n) -&gt; Result(Image, Snag)\n Add a solid border around the passed image, expanding the \n dimensions of the image by the border thickness. Replaces any transparent\n pixels with the color of the border. This can be used with the round\n function to add a rounded border to an image.\nSynonyms:\nansel/image.border\nansel/image border","url":"ansel/image.html#border"},{"doc":"ansel/image","title":"composite_over","content":"pub fn composite_over(\n  base base: Image,\n  with overlay: Image,\n  at_left l: Int,\n  at_top t: Int,\n) -&gt; Result(Image, Snag)\n Places an image over another image, with the top left corner of the\n overlay image placed at the specified coordinates.\nSynonyms:\nansel/image.composite_over\nansel/image composite_over","url":"ansel/image.html#composite_over"},{"doc":"ansel/image","title":"create_thumbnail","content":"pub fn create_thumbnail(\n  from path: String,\n  width width: Int,\n) -&gt; Result(Image, Snag)\n Creates a thumbnail of an image at the specified path with the given width.\nSynonyms:\nansel/image.create_thumbnail\nansel/image create_thumbnail","url":"ansel/image.html#create_thumbnail"},{"doc":"ansel/image","title":"extract_area","content":"pub fn extract_area(\n  from image: Image,\n  at bounding_box: BoundingBox,\n) -&gt; Result(Image, Snag)\n Extracts an area out of an image, resulting in a new image of the \n extracted area.\nSynonyms:\nansel/image.extract_area\nansel/image extract_area","url":"ansel/image.html#extract_area"},{"doc":"ansel/image","title":"fill","content":"pub fn fill(\n  image: Image,\n  in bounding_box: BoundingBox,\n  with color: Color,\n) -&gt; Result(Image, Snag)\n Fills in an area of the passed image with a solid color. \nSynonyms:\nansel/image.fill\nansel/image fill","url":"ansel/image.html#fill"},{"doc":"ansel/image","title":"fit_bounding_box","content":"pub fn fit_bounding_box(\n  bounding_box bounding_box: BoundingBox,\n  in image: Image,\n) -&gt; Result(BoundingBox, Snag)\n Fits a fixed bounding box to an image by dropping any pixels outside the\n dimensions of the image.\n \n ## Example\n \n \n let assert Ok(bb) = bounding_box.ltwh(4, 2, 40, 30)\n let assert Ok(img) = image.new(6, 7, color.GleamLucy)\n image.fit_bounding_box(bb, in: img)\n // -&gt; bounding_box.ltwh(left: 4, top: 2, width: 2, height: 5)\n \nSynonyms:\nansel/image.fit_bounding_box\nansel/image fit_bounding_box","url":"ansel/image.html#fit_bounding_box"},{"doc":"ansel/image","title":"from_bit_array","content":"pub fn from_bit_array(bin: BitArray) -&gt; Result(Image, Snag)\n Reads a vips image from a bit array\n \n ## Example\n \n simplifile.read_bits(&quot;input.jpeg&quot;)\n |&gt; result.try(image.from_bit_array)\n // -&gt; Ok(ansel.Image)\n \nSynonyms:\nansel/image.from_bit_array\nansel/image from_bit_array","url":"ansel/image.html#from_bit_array"},{"doc":"ansel/image","title":"get_height","content":"pub fn get_height(image: Image) -&gt; Int\n Returns the height of an image.\nSynonyms:\nansel/image.get_height\nansel/image get_height","url":"ansel/image.html#get_height"},{"doc":"ansel/image","title":"get_width","content":"pub fn get_width(image: Image) -&gt; Int\n Returns the width of an image.\nSynonyms:\nansel/image.get_width\nansel/image get_width","url":"ansel/image.html#get_width"},{"doc":"ansel/image","title":"new","content":"pub fn new(\n  width width: Int,\n  height height: Int,\n  color color: Color,\n) -&gt; Result(Image, Snag)\n Creates a new image with the specified width, height, and color\n \n ## Example\n \n image.new(6, 6, color.Olive)\n // -&gt; Ok(ansel.Image)\n \nSynonyms:\nansel/image.new\nansel/image new","url":"ansel/image.html#new"},{"doc":"ansel/image","title":"outline","content":"pub fn outline(\n  in image: Image,\n  area bounding_box: BoundingBox,\n  with color: Color,\n  thickness thickness: Int,\n) -&gt; Result(Image, Snag)\n Outlines an area in the passed image with a solid color. All\n outline pixels are written inside the bounding box area.\nSynonyms:\nansel/image.outline\nansel/image outline","url":"ansel/image.html#outline"},{"doc":"ansel/image","title":"read","content":"pub fn read(from path: String) -&gt; Result(Image, Snag)\n Reads an image from the specified path.\nSynonyms:\nansel/image.read\nansel/image read","url":"ansel/image.html#read"},{"doc":"ansel/image","title":"rotate","content":"pub fn rotate(\n  image image: Image,\n  by degrees: Float,\n) -&gt; Result(Image, Snag)\n Rotates an image by the given number of degrees.\nSynonyms:\nansel/image.rotate\nansel/image rotate","url":"ansel/image.html#rotate"},{"doc":"ansel/image","title":"round","content":"pub fn round(\n  image image: Image,\n  by radius: Float,\n) -&gt; Result(Image, Snag)\n Rounds the corners of an image by a given radius, leaving transparent \n pixels where the rounding was applied. A large radius can be given to \n create circular images. This can be used with the border function to \n create rounded borders around images. This implmentation is heavily \n inspired by the extensive elixir library Image.\nSynonyms:\nansel/image.round\nansel/image round","url":"ansel/image.html#round"},{"doc":"ansel/image","title":"scale","content":"pub fn scale(\n  image img: Image,\n  by scale: Float,\n) -&gt; Result(Image, Snag)\n Resizes an image by the given scale, preserving the aspect ratio.\nSynonyms:\nansel/image.scale\nansel/image scale","url":"ansel/image.html#scale"},{"doc":"ansel/image","title":"scale_height","content":"pub fn scale_height(\n  image img: Image,\n  to target: Int,\n) -&gt; Result(Image, Snag)\n Scales an image to the given height, preserving the aspect ratio.\nSynonyms:\nansel/image.scale_height\nansel/image scale_height","url":"ansel/image.html#scale_height"},{"doc":"ansel/image","title":"scale_width","content":"pub fn scale_width(\n  image img: Image,\n  to target: Int,\n) -&gt; Result(Image, Snag)\n Scales an image to the given width, preserving the aspect ratio.\nSynonyms:\nansel/image.scale_width\nansel/image scale_width","url":"ansel/image.html#scale_width"},{"doc":"ansel/image","title":"to_bit_array","content":"pub fn to_bit_array(img: Image, format: ImageFormat) -&gt; BitArray\n Saves a vips image to a bit array. Assumes your vips was built with the\n correct encoder support for the format to save in.\n \n ## Example\n \n image.new(6, 6, color.GleamLucy)\n |&gt; result.map(to_bit_array(_, ansel.PNG))\n |&gt; result.try(simplifile.write_bits(&quot;output.png&quot;))\n \nSynonyms:\nansel/image.to_bit_array\nansel/image to_bit_array","url":"ansel/image.html#to_bit_array"},{"doc":"ansel/image","title":"to_bounding_box","content":"pub fn to_bounding_box(image image: Image) -&gt; BoundingBox\n Returns the dimensions of an image as a bounding box. Useful for bounding\n box operations.\nSynonyms:\nansel/image.to_bounding_box\nansel/image to_bounding_box","url":"ansel/image.html#to_bounding_box"},{"doc":"ansel/image","title":"write","content":"pub fn write(\n  image img: Image,\n  to path: String,\n  in format: ImageFormat,\n) -&gt; Result(Nil, Snag)\n Writes an image to the specified path in the specified format.\nSynonyms:\nansel/image.write\nansel/image write","url":"ansel/image.html#write"},{"doc":"ansel/image","title":"ansel/image","content":" This module is primarily a wrapper around the Elixir package Vix, which\n is a wrapper around the great image processing library vips. A pre-built\n vips binary comes with Vix, but see the readme for more information on\n how to bring your own to support more image formats.\n \n This module uses the [snag package](https://hexdocs.pm/snag/index.html) for \n error handling because vix errors just come back as strings and are not \n enumerated. Make sure to install it as well to work with the error messages.\n \n ```gleam\n import ansel\n import ansel/image\n import gleam/result\n import snag\n\n pub fn main() {\n   let assert Ok(img) = image.read(&quot;input.jpeg&quot;)\n\n   image.scale(img, by: 2.0)\n   |&gt; result.try(\n     image.write(_, &quot;output&quot;, ansel.JPEG(quality: 60, keep_metadata: False)),\n   )\n   |&gt; snag.context(&quot;Unable to process my cool image&quot;)\n }\n // -&gt; output.jpeg written to disk as a smaller, rounded, bordered version of the\n //    original image\n ```","url":"ansel/image.html"}]);